#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_MTWO_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_MTWO_HPP_INCLUDED

#include <boost/simd/constant/include/constants/mtwo.hpp>

#endif
